import freenit.api.user

from .router import api
